/*
** Module   : LockTypeException.java
** Abstract : Exception thrown when lock/nowait values do not correspond to a valid lock type.
**
** Copyright (c) 2014, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 VMN 20140330 Created initial version.
*/

package com.goldencode.p2j.persist.lock;

/**
 * This exception is thrown when lock/nowait int values do not correspond to a valid lock type.
 */
public class LockTypeException
extends Exception
{
   /** Whether the lock value is correct. */
   private boolean lockCorrect;

   /** Whether the nowait value is correct. */
   private boolean nowaitCorrect;

   /**
    * Constructor which accepts lock and nowait correctness flags.
    *
    * @param   lockCorrect
    *          <code>true</code> if lock value is correct.
    * @param   nowaitCorrect
    *          <code>true</code> if nowait value is correct.
    */
   public LockTypeException(boolean lockCorrect, boolean nowaitCorrect)
   {
      this.lockCorrect = lockCorrect;
      this.nowaitCorrect = nowaitCorrect;
   }

   /**
    * Reports whether lock value is correct.
    *
    * It is not used so far.
    *
    * @return   <code>true</code> if lock value is correct.
    */
   public boolean isLockCorrect()
   {
      return lockCorrect;
   }

   /**
    * Reports whether nowait value is correct.
    *
    * @return   <code>true</code> if nowait value is correct.
    */
   public boolean isNowaitCorrect()
   {
      return nowaitCorrect;
   }
}
